
# Paths to data ####

data.source = "F00005809-WV6_Data_spss_v_2016_01_01.zip" # htts://worldvaluessurvey.org


# Libs ####
library("haven")
library("lme4")
library("ggplot2")
library("ggrepel")
library("stargazer")
library("effectsize")
library("htmltools")
library("effects")
library("WDI")
library("reshape2")
library("readxl")
library("sjmisc")
library("car")


# Data transformation #####
wvs6 <- haven::read_sav(data.source)


wvs6$country <- sjmisc::to_label(wvs6$V2)
wvs6$country <- droplevels(wvs6$country)

# rename variables
varnames <- data.frame(
  old= c("V158", "V159", "V240", "V242", "V248", "V239"),
  new=c("sss40", "sss70", "female", "age", "edu", "income")
  )

for(i in 1:nrow(varnames)) {
  
  names(wvs6)[names(wvs6)==varnames[i, "old"]] <- varnames[i, "new"]
  
}


# Adding country-level data

codes <- data.frame(WDI_data$country, stringsAsFactors = F)[1:3]

wvs6$country.c <- as.character(wvs6$country)
wvs6$country.c <-
  car::recode(wvs6$country.c, "
              'Egypt'='Egypt, Arab Rep.';
              'Hong Kong'='Hong Kong SAR, China';
              'Iran'='Iran, Islamic Rep.';
              'Russia'='Russian Federation';
              'Serbia and Montenegro'='Serbia';
              'South Korea'='Korea, Rep.';
              'Taiwan'='Taiwan, China';
              'Great Britain'='United Kingdom';
              'Viet Nam'='Vietnam';
              'Kyrgyzstan'='Kyrgyz Republic';
              'Palestine'='PS';
              'Yemen'='Yemen, Rep.';")

wvs6$iso2c<-wvs6$country.c
for(x in 1:nrow(codes)) {
  wvs6$iso2c[wvs6$iso2c == codes[x, "country"]] <- codes[x, "iso2c"]
}

# Download country data -- downloaded on december 2020
# country.vars1=WDI(unique(wvs6$iso2c), c(
#                         #Modernization index
#                           life.exp="SP.DYN.LE00.IN", # Life expectancy at birth, total (years)
#                           schooling.yrs="UIS.SLE.56", # School life expectancy, tertiary, both sexes (years)
#                           enrollment.tertiary= "SE.TER.ENRR", # School enrollment, tertiary (% gross)
#                           enrollment.secondary = "SE.SEC.NENR", # % Net
#                           gov.ed.expend.total = "SE.XPD.TOTL.GD.ZS", # Government expenditure on education, total (% of GDP)
#                           gov.ed.expend.secondary = "SE.XPD.SECO.PC.ZS", #Government expenditure per student, secondary (% of GDP per capita)
#                           urbanization="SP.URB.TOTL.IN.ZS",  # Urban population (% of total)
#                           gdp.pc=    "NY.GDP.PCAP.PP.CD", # GDP per capita, PPP (current international $)
#                           gni.pc.ppp="NY.GNP.PCAP.PP.CD", # GNI per capita, PPP (current international $)
#                           gni.pc.atlas = "NY.GNP.PCAP.CD", #GNI per capita, Atlas method (current US$)
#                           # * proportion of older people (aged 65 years and older;
#                           pop.65plus="SP.POP.65UP.TO.ZS", #Population ages 65 and above (% of total)
# ), start=2002, end=2016, extra=T)
load("wdi.Rdata")



#table of how many non-NAs in 2014
apply(country.vars1[country.vars1$year==2012,], 2, function(x) sum(!is.na(x)))

#..Fill the missings #####

fill.wdi <- function(goal, ind, wdi.dat) {
  
  a<-lapply(ind, function(ind.loop) { 
    u<-lapply(unique(wdi.dat$country), function(x) {
      
      subs.c <- wdi.dat[wdi.dat$country==x,c("country", "year", ind.loop)]
      subs.c <- subs.c[!is.na(subs.c[,ind.loop]),]
      subs.c <- subs.c[sort(abs(subs.c$year-goal), index.return = T)$ix,]
      subs.c <- subs.c[1,c("country","year", ind.loop)]
      subs.c$country <- x
      names(subs.c)[names(subs.c)=="year"]<- paste0("year",ind.loop)
      subs.c
    })
    return(Reduce("rbind", u))
  })
  
  a1 = lapply(a, function(x) x[-2])
  out = Reduce(function(b, d) merge(b, d, by = "country", all=T), a1)
  
  a2 = lapply(a, function(x) x[-3])
  years = Reduce(function(b, d) merge(b, d, by = "country", all=T), a2)
  
  return(list(out, years))

}

country.vars.filled<-fill.wdi(goal = 2012,
                              ind=c('life.exp', 'schooling.yrs', 
                                    'enrollment.tertiary', 'enrollment.secondary', 
                                    'gov.ed.expend.total', 'gov.ed.expend.secondary', 
                                    'urbanization', 
                                    'gdp.pc', 'gni.pc.ppp', 'gni.pc.atlas', 
                                    'pop.65plus', 
                                    'pop.65plus.female', 'gini', "iso2c"),
                              wdi.dat = country.vars1)[[1]]



#table how many non-NAs after filling
apply(country.vars.filled, 2, function(x) sum(!is.na(x)))

#put back iso2c 
country.vars.filled$iso2c <- sapply(country.vars.filled$country, 
                                    function(x) country.vars$iso2c[country.vars$country==x][1])


#..compute modernization index ####

country.vars.filled$log.gdp.pc <- log(country.vars.filled$gdp.pc)

#PCA
pc.modern<-princomp(na.omit(cbind(
  country.vars.filled[,"pop.65plus"],
  country.vars.filled[,"schooling.yrs"],
  country.vars.filled[,"urbanization"],
  country.vars.filled[,"log.gdp.pc"])),
  scores=T)
summary(pc.modern)


# Additive `modernization` index
country.vars.filled$ind.modern<-scale(
  #scale(country.vars.filled$life.exp)+
  scale(country.vars.filled$pop.65plus)+
    scale(country.vars.filled$schooling.yrs) +
    scale(country.vars.filled$urbanization) +
    scale(country.vars.filled$log.gdp.pc)
)

psych::alpha(country.vars.filled[, c("pop.65plus",
                                     "schooling.yrs" , 
                                     "urbanization",
                                     "log.gdp.pc")])
psych::omegaSem(country.vars.filled[, c("pop.65plus",
                                        "schooling.yrs" , 
                                        "urbanization",
                                        "log.gdp.pc")],
                nfactors=1, fm="ml")

cor(country.vars.filled[, c("pop.65plus",
                            "schooling.yrs" , 
                            "urbanization",
                            "log.gdp.pc",
                            "life.exp")])

ggplot(country.vars.filled, aes(pop.65plus, life.exp, label = country))+geom_point(color="red")+geom_text_repel()

#..merge with individual data ####

wvs6c<-merge(wvs6, country.vars.filled, by="iso2c", all.x=T)
wvs6c$country.y<-NULL
wvs6c$country.c<-NULL
wvs6c$country<-wvs6c$country.x


# clear memory
rm(country.vars,country.vars1, country.vars.filled, codes, fill.wdi, 
   empl.older.ilo, 
   soc.spend65.ilo,
   pc.modern, varnames,x,i,empl.older.file, data.source, soc.spend65.file,
   wvs6
)


# standardizing #####
wvs6c$log.gni.pc.ppp <- log(wvs6c$gni.pc.ppp)
wvs6c$log.gni.pc.atlas <- log(wvs6c$gni.pc.atlas)

wvs6c$g.income <- wvs6c$income
for(v in unique(wvs6c$country))  {
  wvs6c[wvs6c$country==v,"g.income"] = as.vector(scale(wvs6c[wvs6c$country==v,"income"]))
}


## Cultural zone coding ####

wvs6c$muslim.countries <- as.numeric(
  wvs6c$country %in% c('Algeria',  
                       'Bahrain',
                       'Egypt',
                       'Kuwait',
                       'Morocco',
                       'Pakistan',
                       'Jordan',
                       'Iraq',
                       'Tunisia',
                       'Libya',
                       'Qatar',
                       'Yemen',
                       'Turkey', 
                       'Palestine',
                       'Lebanon',
                       "Malaysia",
                       "Azerbaijan",
                       "Kazakhstan",
                       "Kyrgyzstan",
                       "Uzbekistan"))

wvs6c$postcommunist.countries <- as.numeric(  
  wvs6c$country %in% c('Armenia' ,
                       'Azerbaijan',
                       'Belarus',
                       'Kazakhstan',
                       'Georgia' ,
                       'Kyrgyzstan',
                       'Estonia',
                       'Romania',
                       'Poland',
                       'Russia',
                       'Slovenia',
                       'Ukraine',
                       'Uzbekistan'))

wvs6c$postcommunist.countries1 <- as.numeric(  
  wvs6c$country %in% c('Armenia' ,
                       'Azerbaijan',
                       'Belarus',
                       'Kazakhstan',
                       'Georgia' ,
                       'Kyrgyzstan',
                       'Estonia',
                       'Romania',
                       'Poland',
                       'Russia',
                       #'Slovenia',
                       'Ukraine',
                       'Uzbekistan'))

wvs6c$LatinAmerica <- as.numeric(  
  wvs6c$country %in% c('Argentina',
                       'Brazil' ,
                       'Chile',
                       'Colombia',
                       'Ecuador',
                       'Mexico',
                       'Peru',
                       'Trinidad and Tobago',
                       'Uruguay'))

wvs6c$NewWorld <- as.numeric(  
  wvs6c$country %in% c('Australia',
                       'New Zealand',
                       'United States',
                       'South Africa'))

wvs6c$OtherEurope <- as.numeric(  
  wvs6c$country %in% c('Germany' ,
                       'Netherlands',
                       'Spain',
                       'Sweden',
                       'Cyprus'))
wvs6c$SouthEastAsia <- as.numeric(  
  wvs6c$country %in% c('China',
                       'Taiwan',
                       'Hong Kong',
                       'South Korea',
                       'Japan',
                       'Malaysia',
                       'Philippines',
                       'Singapore',
                       'Thailand',
                       'India'))
wvs6c$SSAfrica <- as.numeric(  
  wvs6c$country %in% c('Rwanda',
                       'Ghana',
                       'Nigeria', 
                       'Zimbabwe'))
wvs6c$EUR.countries <-  as.numeric(
  wvs6c$country %in% c('Belarus', 
                       'Cyprus', 
                       'Germany', 
                       'Estonia', 
                       'Spain', 
                       'Netherlands', 
                       'Poland', 
                       'Romania', 
                       'Russia', 
                       'Sweden', 
                       'Slovenia', 
                       'Ukraine'))

# Descriptive  ####


mdl<-lm(sss70 ~ sss40, wvs6c)
wvs6c$resid<-rep(NA, nrow(wvs6c))
wvs6c$resid[rowSums(is.na(wvs6c[, c("sss70", "sss40")]))==0  ] <- resid(mdl)



# Figure 1 ####
#  country means for graph

gr.dat <-data.frame(modernization=tapply(wvs6c$ind.modern, wvs6c$country, mean, na.rm=T),
                    sss70=tapply(wvs6c$resid, wvs6c$country, mean, na.rm=T),
                    country=row.names(tapply(wvs6c$resid, wvs6c$country, mean, na.rm=T)))
gr.dat<-na.omit(gr.dat)
gr.dat$Europe <- gr.dat$country %in% unique(wvs6c$country[wvs6c$EUR.countries==1])
gr.dat$Muslim <- gr.dat$country %in% unique(wvs6c$country[wvs6c$muslim.countries==1])
gr.dat$LatinAmerica <- gr.dat$country %in% unique(wvs6c$country[wvs6c$LatinAmerica==1])
gr.dat$NewWorld <- gr.dat$country %in% unique(wvs6c$country[wvs6c$NewWorld==1])
gr.dat$SSAfrica <- gr.dat$country %in% unique(wvs6c$country[wvs6c$SSAfrica==1])
gr.dat$SouthEastAsia <- gr.dat$country %in% unique(wvs6c$country[wvs6c$SouthEastAsia==1])
gr.dat$postcom <- gr.dat$country %in% unique(wvs6c$country[wvs6c$postcommunist.countries==1])
gr.dat$postcom1 <- gr.dat$country %in% unique(wvs6c$country[wvs6c$postcommunist.countries1==1])


ggplot(gr.dat, aes(modernization, sss70))+
  geom_smooth(method = "lm",  se = F, color = "#27408B88", size=3)+
  geom_smooth(data = gr.dat[gr.dat$Muslim,], method = "lm", col = "#00CD0088", se = F, size=3)+
  geom_smooth(data = gr.dat[gr.dat$postcom1,], method = "lm", col = "#FF303088", se = F, size=3)+
  # geom_smooth(data = gr.dat[gr.dat$Europe,], method = "lm", col = "blue", se = F, size=2)+
  
  geom_point(aes(fill = Muslim, color = as.factor(postcom1)), stroke = 1.2, size= 3, shape = 21)+
  #scale_shape_manual(values = c(21, 25))+
  scale_color_manual(values = c("black", "red"))+
  scale_fill_manual(values = c("lightgrey", "#00CD00"))+
  geom_point( data = gr.dat[!gr.dat$Muslim & !gr.dat$postcom1,],  size= 3, shape = 21, fill = "grey")+
  geom_point( data = gr.dat[gr.dat$SSAfrica,],  size= 3, shape = 21, fill = "black")+
  geom_point( data = gr.dat[gr.dat$LatinAmerica,],  size= 3, shape = 21, fill = "yellow")+
  geom_point( data = gr.dat[gr.dat$NewWorld,],  size= 3, shape = 21, fill = "lightskyblue")+
  geom_point( data = gr.dat[gr.dat$SSAfrica,],  size= 3, shape = 21, fill = "black")+
  geom_point( data = gr.dat[gr.dat$SouthEastAsia,],  size= 3, shape = 21, fill = "purple", alpha=.5)+
  geom_point( data = gr.dat[gr.dat$Europe,],  size= 2, shape = 21, fill = "blue", color="blue")+
  geom_text_repel(aes(label = stringr::str_wrap(country, 10)), size=3.3, box.padding = 0.4, min.segment.length = 0.7, segment.colour="grey")+
  xlim(-3,3)+
  ylab("Social status of people in their 70s (adjusted)")+
  xlab("Modernization index")+
  theme_mr()

# b&w version
ggplot(gr.dat, aes(modernization, sss70))+
  geom_smooth(method = "lm",  se = F, color = "grey", size=3, linetype = "solid")+
  geom_smooth(data = gr.dat[gr.dat$Muslim,], method = "lm", col = "darkgrey", se = F, size=2, linetype = "longdash")+
  geom_smooth(data = gr.dat[gr.dat$postcom1,], method = "lm", col = "darkgrey", se = F, size=2, linetype = "dotdash")+

  #geom_point( data = gr.dat[!gr.dat$Muslim & gr.dat$postcom1 & !gr.dat$Europe,],  size= 1, shape = 8)+
  geom_point( data = gr.dat[gr.dat$SSAfrica,],  size= 1, shape = 15)+
  geom_point( data = gr.dat[gr.dat$LatinAmerica,],  size= 1, shape = 16)+
  geom_point( data = gr.dat[gr.dat$NewWorld,],  size= 1, shape = 23, fill = "black")+
  geom_point( data = gr.dat[gr.dat$SSAfrica,],  size= 1, shape = 17)+
  geom_point( data = gr.dat[gr.dat$SouthEastAsia,],  size= 1, shape = 25, fill = "black")+
  geom_point( data = gr.dat[gr.dat$Europe,],  size= 1, shape = 8)+

  geom_point( data = gr.dat[gr.dat$postcom1,],  size= 3, shape = 21, fill = NA, stroke = 1)+
  geom_point( data = gr.dat[gr.dat$Muslim,],  size= 4, shape = 22, fill = NA)+
  
  geom_text_repel(aes(label = stringr::str_wrap(country, 10)), size=3.3, box.padding = 0.4, min.segment.length = 0.7, segment.colour="grey")+
  xlim(-3,3)+
  ylab("Social status of people in their 70s (adjusted)")+
  xlab("Modernization index")+
  theme_mr()


# Overall correlation
cor.test(gr.dat$modernization, gr.dat$sss70)
# Europe correlation
cor.test(gr.dat$modernization[gr.dat$Europe], gr.dat$sss70[gr.dat$Europe])
# Muslim correlation
cor.test(gr.dat$modernization[gr.dat$Muslim], gr.dat$sss70[gr.dat$Muslim])
# Postcom correlation

cor.test(gr.dat$modernization[gr.dat$postcom1], gr.dat$sss70[gr.dat$postcom1])

# Dropping outliers: Japan and Germany
cor.test(gr.dat$modernization[!gr.dat$country %in% c("Japan", "Germany")], 
         gr.dat$sss70[!gr.dat$country %in% c("Japan", "Germany")])

# Including Slovenia to postcom 
cor.test(gr.dat$modernization[gr.dat$postcom],  gr.dat$sss70[gr.dat$postcom])

# MODELS ####

wvs_nomis <- wvs6c [rowSums(is.na(wvs6c[,c("ind.modern", "log.gdp.pc", "pop.65plus", "schooling.yrs", "urbanization")]))==0,]


merTools::ICC("sss70", "country", wvs_nomis)

m1 <- lmer(scale(sss70) ~ scale(sss40) + scale(female) + scale(age) + g.income + scale(edu) + (1|country), wvs_nomis)


#Simple
m2 <- update(m1, . ~ . + scale(ind.modern) + I(scale(ind.modern)^2 ))
m3 <- update(m1, . ~ . + scale(log.gdp.pc)  + I(scale(log.gdp.pc)^2))
m4 <- update(m1, . ~ . + scale(pop.65plus)  + I(scale(pop.65plus)^2))#g.exp.life.exp
m5 <- update(m1, . ~ . + scale(schooling.yrs)  + I(scale(schooling.yrs)^2))
m6 <- update(m1, . ~ . + scale(urbanization)   + I(scale(urbanization)^2))
m7 <- update(m1, . ~ . + scale(log.gdp.pc) + 
               scale(pop.65plus) + 
               scale(schooling.yrs) + 
               scale(urbanization))

m7a <- update(m1, . ~ . 
              + scale(log.gdp.pc) +I(scale(log.gdp.pc)^2)
              + scale(pop.65plus) + I(scale(pop.65plus)^2)
              + scale(schooling.yrs) + 
                scale(urbanization) + I(scale(urbanization)^2))

m7b <- update(m1, . ~ . 
              + scale(log.gdp.pc) 
              + scale(pop.65plus) + I(scale(pop.65plus)^2)
              + scale(schooling.yrs) + 
                scale(urbanization))

#  Bootstrap CI function 

make_tab_boot_ci <- function(models.list, 
                             file.boot.run="bootsttrapped.cis.Rdata") {
  
  require(stargazer); require(htmltools)
  
  mdls = models.list
  
  bootsttrapped.mdls = lapply(mdls, function(x) {
    confint.merMod(x, seed=4321, nsim=500, method = "boot", 
                   boot.type="perc", oldNames = F)
  })
  save(bootsttrapped.mdls, file = file.boot.run)
  
  M0 <-
    lapply(mdls, function(x)
      update(x,  paste(".~ 1+ (1|",   names(getME( x, "flist")), ")")))
  R2.intercept = sapply(1:length(M0), function(x) 
    
    (attr(lme4::VarCorr(M0[[x]])[[1]], "stddev")[[1]] ^ 2 -
       attr(lme4::VarCorr(mdls[[x]])[[1]], "stddev")[[1]] ^ 2)/
      attr(lme4::VarCorr(M0[[x]])[[1]], "stddev")[[1]] ^ 2 
  ) 
  
  do.call("stargazer", list(mdls, 
                            ci.custom = bootsttrapped.mdls, 
                            #apply.ci = function(x) gsub("\\(", "\\[", x),
                            keep.stat=c('rsq'),
                            digits=2, ci.separator = ", ",single.row = F,
                            style = "all2",
                            align=T,initial.zero=F,
                            star.cutoffs = c(.05, .01, .001),
                            add.lines = list(c("deviance", 
                                               sapply(mdls, function(x) 
                                                 format(
                                                   round(
                                                     deviance(x,REML=FALSE) 
                                                     ), 
                                                   nsmall=0, 
                                                   big.mark=","
                                                   )
                                                 )
                                               ),
                                             
                                             c("Nparameters", round(sapply(mdls, function(x) attr(logLik(x), "df")))), 
                                             #c("max.vif", round(sapply(mdls, function(x) max(car::vif(x))), 1)),
                                             c("AIC", sapply(mdls, 
                                                                   function(x) 
                                                                     format(
                                                                       round(as.numeric(
                                                                         lme4:::extractAIC.merMod(x)[[2]])
                                                                       ), 
                                                                       nsmall=0, 
                                                                       big.mark=","
                                                                     )
                                                                      )),
                                             c("BIC", sapply(mdls, 
                                                                   function(x) 
                                                                     format(
                                                                       round(
                                                                         BIC(x) 
                                                                       ), 
                                                                       nsmall=0, 
                                                                       big.mark=","
                                                                     ) 
                                                                     
                                                                   
                                                                   )),
                                             c("R2.intercept", 
                                               sub("^(-?)0.", "\\1.", sprintf("%.2f", round(R2.intercept,2)))
                                               
                                               )
                                             
                            ),
                            type = "html")) %>% HTML() %>% browsable()
  
}

# Table 1 ####
make_tab_boot_ci(models.list=list(m2, m3, m4, m5, m6, m7, m7a, m7b), 
                 file.boot.run="bootsttrapped.m2_m7b.Rdata")


# Interactions with main effects ####

b1 <- update(m1, . ~ . + LatinAmerica +NewWorld + SouthEastAsia+ SSAfrica + muslim.countries  + postcommunist.countries1) #OtherEurope

b2 <- update(m1, . ~ . + LatinAmerica +NewWorld + SouthEastAsia+ SSAfrica + muslim.countries  + postcommunist.countries1 + scale(ind.modern)) #OtherEurope

b3 <- update(m1, . ~ . + scale(ind.modern) +   
               scale(ind.modern)*muslim.countries  + 
               scale(ind.modern)*postcommunist.countries1)

b4 <- update(m1, . ~ . + muslim.countries  + postcommunist.countries1 + scale(pop.65plus) + I(scale(pop.65plus)^2))

# Table 2 ####
make_tab_boot_ci(models.list=list(b1, b2, b3, b4), 
                 file.boot.run="bootsttrapped.b1_b4.Rdata")


# Effect sizes - b3 ####
summary(b3)
b3.sum <- summary(b3)

# muslim slope
b3.sum$coefficients["scale(ind.modern)","t value"] + 
  b3.sum$coefficients["scale(ind.modern):muslim.countries","t value"] 
effectsize::t_to_eta2(-2.988157, df=57, ci=.95) 

# non-muslim, non-postcom slope
b3.sum$coefficients["scale(ind.modern)","t value"]  
effectsize::t_to_eta2(-4.968517, df=57, ci=.95)

# postcom slope
b3.sum$coefficients["scale(ind.modern)","t value"] + 
  b3.sum$coefficients["scale(ind.modern):postcommunist.countries1","t value"] 
effectsize::t_to_eta2(-7.695551, df=57, ci=.95)

# FIGURE 2 #####
wvs_nomis.s <- wvs_nomis
for(v in names(wvs_nomis.s)) wvs_nomis.s[,v]<-unclass(wvs_nomis.s[,v])
b3 <- update(b3, data = wvs_nomis.s)

all.d <- effects::effect(term= "scale(ind.modern)", 
                         xlevels=list(ind.modern = seq(-2, 1.5, by=0.5)),
                         mod=b3)

postcom.d <- effects::effect(term= "scale(ind.modern):postcommunist.countries1",       
                             xlevels=list(postcommunist.countries1=c(0, 1),
                                          ind.modern =  seq(-2, 1.5, by=0.5)),
                             mod=b3)
musl.d <- effects::effect(term= "scale(ind.modern):muslim.countries",       
                          xlevels=list(ind.modern =  seq(-2, 1.5, by=0.5), muslim.countries=c(0, 1)
                          ),
                          mod=b3)
gr.dat <- rbind(
  as.data.frame(all.d),
  as.data.frame(postcom.d)[9:16,-2],
  as.data.frame(musl.d)[9:16,-2])
gr.dat$group = c(rep("Overall", 8), 
                 rep("Postcommunist", 8), 
                 rep("Muslim", 8))

ggplot(gr.dat, aes(ind.modern, fit, color = group, fill = group))+
  geom_ribbon(aes(ymin = lower, ymax = upper), alpha = .3, color = NA)+
  geom_line(aes(linetype = group))+
  # scale_color_manual(values = c("green", "black", "red"), name = "Cultural zone")+
  # scale_fill_manual(values = c("green", "black", "red"), name = "Cultural zone")+
  # bw version below
  scale_color_manual(values = c("grey50", "black", "black"), name = "Cultural zone")+
  scale_fill_manual(values = c("grey50", "grey50", "grey50"), guide=NULL)+
  scale_linetype_manual(values = c("longdash", "solid", "dotdash"), name = "Cultural zone")+
  #xlim(-3, 3)+ylim(-3,3)+
  theme_bw()+labs(x="Modernization index", y = "Social status of people in their 70s (adjusted)")

# APPENDICES #####
## Appendix A ####

wvs6c$missing <- rowSums(is.na(wvs6c[,c(
  'sss70', 'sss40', 'female', 'age', 'income', 'edu', 
  "ind.modern", "log.gdp.pc", "pop.65plus", "schooling.yrs", 
  "urbanization")]))!=0

wvs6c.no.mis <- wvs6c[!wvs6c$missing & !(wvs6c$country %in% c("Taiwan", "Hong Kong")), ]
wvs6c.no.mis$country <- droplevels(wvs6c.no.mis$country)


descr.tabA1 <- data.frame(
  Sample.size.na.omit = table(wvs6c.no.mis$country),
  Percent.female  = prop.table(table(wvs6c.no.mis$country, wvs6c.no.mis$female), 1)[,2],
  Percent.missing = prop.table(table(droplevels(wvs6c[!(wvs6c$country %in% c("Taiwan", "Hong Kong")),"country"]), 
                                     wvs6c[!(wvs6c$country %in% c("Taiwan", "Hong Kong")),"missing"]), 1)[,2],
  Mean.age = aggregate(age ~ country, wvs6c.no.mis, mean, na.rm = T),
  LatinAmerica = table(wvs6c.no.mis$country, wvs6c.no.mis$LatinAmerica)[,2],
  
  NewWorld = table(wvs6c.no.mis$country, wvs6c.no.mis$NewWorld)[,2],
  muslim.countries = table(wvs6c.no.mis$country, wvs6c.no.mis$muslim.countries)[,2],
  OtherEurope = table(wvs6c.no.mis$country, wvs6c.no.mis$OtherEurope)[,2],
  postcommunist.countries1 = table(wvs6c.no.mis$country, wvs6c.no.mis$postcommunist.countries1)[,2],
  SSAfrica = table(wvs6c.no.mis$country, wvs6c.no.mis$SSAfrica)[,2],
  SouthEastAsia = table(wvs6c.no.mis$country, wvs6c.no.mis$SouthEastAsia)[,2]
)

descr.tabA1 <- descr.tabA1[, -c(1,5)]
tot.line = colSums(descr.tabA1)
tot.line["Sample.size.na.omit.Freq"] <- nrow(wvs6c.no.mis)
tot.line["Percent.female"] <- prop.table(table(wvs6c.no.mis$female))[2]
tot.line["Percent.missing"] <- prop.table(table(wvs6c[!(wvs6c$country %in% c("Taiwan", "Hong Kong")),"missing"]))[2]
tot.line["Mean.age.age"] <- mean(wvs6c.no.mis$age, na.rm = T)

descr.tabA1 <-  rbind(descr.tabA1, total=tot.line)
df_to_viewer(descr.tabA1, kable = T, colformat = c(Percent.female = 2, Percent.missing = 2, Mean.age.age=1))


## Appendix B #####
## Robustness tests of the impact of share of people 65+

### Figure B ####

gr.dat <-data.frame(pop.65=tapply(wvs6c$pop.65plus, wvs6c$country, mean, na.rm=T),
                    sss70=tapply(wvs6c$resid, wvs6c$country, mean, na.rm=T),
                    country=row.names(tapply(wvs6c$resid, wvs6c$country, mean, na.rm=T)))
gr.dat$Europe <- gr.dat$country %in% unique(wvs6c$country[wvs6c$EUR.countries==1])
gr.dat$Muslim <- gr.dat$country %in% unique(wvs6c$country[wvs6c$muslim.countries==1])
gr.dat$LatinAmerica <- gr.dat$country %in% unique(wvs6c$country[wvs6c$LatinAmerica==1])
gr.dat$NewWorld <- gr.dat$country %in% unique(wvs6c$country[wvs6c$NewWorld==1])
gr.dat$SSAfrica <- gr.dat$country %in% unique(wvs6c$country[wvs6c$SSAfrica==1])
gr.dat$SouthEastAsia <- gr.dat$country %in% unique(wvs6c$country[wvs6c$SouthEastAsia==1])
gr.dat$postcom <- gr.dat$country %in% unique(wvs6c$country[wvs6c$postcommunist.countries==1])
gr.dat$postcom1 <- gr.dat$country %in% unique(wvs6c$country[wvs6c$postcommunist.countries1==1])

ggplot(gr.dat, aes(pop.65, sss70))+
  geom_smooth(method = "lm",  se = F, color = "#27408B88", size=3)+
  geom_smooth(data = gr.dat[gr.dat$Muslim,], method = "lm", col = "#00CD0088", se = F, size=3)+
  geom_smooth(data = gr.dat[gr.dat$postcom1,], method = "lm", col = "#FF303088", se = F, size=3)+
  # geom_smooth(data = gr.dat[gr.dat$Europe,], method = "lm", col = "blue", se = F, size=2)+
  
  geom_point(aes(fill = Muslim, color = as.factor(postcom1)), stroke = 1.2, size= 3, shape = 21)+
  #scale_shape_manual(values = c(21, 25))+
  scale_color_manual(values = c("black", "red"))+
  scale_fill_manual(values = c("lightgrey", "#00CD00"))+
  geom_point( data = gr.dat[!gr.dat$Muslim & !gr.dat$postcom1,],  size= 3, shape = 21, fill = "grey")+
  geom_point( data = gr.dat[gr.dat$SSAfrica,],  size= 3, shape = 21, fill = "black")+
  geom_point( data = gr.dat[gr.dat$LatinAmerica,],  size= 3, shape = 21, fill = "yellow")+
  geom_point( data = gr.dat[gr.dat$NewWorld,],  size= 3, shape = 21, fill = "lightskyblue")+
  geom_point( data = gr.dat[gr.dat$SSAfrica,],  size= 3, shape = 21, fill = "black")+
  geom_point( data = gr.dat[gr.dat$SouthEastAsia,],  size= 3, shape = 21, fill = "purple", alpha=.5)+
  geom_point( data = gr.dat[gr.dat$Europe,],  size= 2, shape = 21, fill = "blue", color="blue")+
  geom_text_repel(aes(label = stringr::str_wrap(country, 10)), size=3.3, box.padding = 0.4, min.segment.length = 0.7, segment.colour="grey")+
  xlim(0,25)+
  ylab("social status of people in their 70s (adjusted)")+
  xlab("% population over 65 y.o.")+
  theme_minimal()


### Table B ####

b1 <- update(m1, . ~ . + scale(pop.65plus) + I(scale(pop.65plus)^2))
b2 <- update(c1, . ~ . + scale(log.gdp.pc))
b3 <- update(c1, . ~ . + scale(schooling.yrs))
b4 <- update(c1, . ~ . + scale(urbanization))

make_tab_boot_ci(models.list=list(b1, b2, b3, b4), 
                 file.boot.run="bootsttrapped.b1_b4.Rdata")




## Appendix C #####
## Interactions between cultural zones and modernization pillars 

c5 <- update(m1, . ~ . + scale(log.gdp.pc)*muslim.countries +       
               scale(log.gdp.pc)*postcommunist.countries1 + scale(pop.65plus))

c6 <- update(m1, . ~ . + scale(pop.65plus)*muslim.countries +       
               scale(pop.65plus)*postcommunist.countries1)

c7 <- update(m1, . ~ . + scale(schooling.yrs)*muslim.countries + 
               scale(schooling.yrs)*postcommunist.countries1+ scale(pop.65plus))

c8 <- update(m1, . ~ . + scale(urbanization)*muslim.countries +       
               scale(urbanization)*postcommunist.countries1+ scale(pop.65plus))

make_tab_boot_ci(models.list=list(c5, c6, c7, c8), 
                 file.boot.run="bootsttrapped.b5_b8.Rdata")





## Appendix D  #####
## Squared terms rubustness 
d1 <- update(m1, . ~ . + muslim.countries  + postcommunist.countries1)
d2 <- update(d1, . ~ . + scale(ind.modern)  + I(scale(ind.modern)^2))
d3 <- update(d1, . ~ . + scale(pop.65plus)  + I(scale(pop.65plus)^2))
d4 <- update(d1, . ~ . + scale(log.gdp.pc)  + I(scale(log.gdp.pc)^2))
d5 <- update(d1, . ~ . + scale(schooling.yrs)  + I(scale(schooling.yrs)^2))
d6 <- update(d1, . ~ . + scale(urbanization)   + I(scale(urbanization)^2))

make_tab_boot_ci(models.list=list(d2, d3, d4, d5, d6), 
                 file.boot.run="bootsttrapped.d2_d6.Rdata")



## Appendix E #####
## Robustness to differing indicators and outliers

### E1 Alternative indicators of economic development (GNIpc ppp and GNIpc Atlas) ####

e2  <- update(m1, . ~ . + scale(log.gni.pc.atlas ))
e3  <- update(m1, . ~ . + scale(log.gni.pc.atlas) + scale(pop.65plus))
e4  <- update(m1, . ~ . + scale(log.gni.pc.ppp))
e5  <- update(m1, . ~ . + scale(log.gni.pc.ppp) + scale(pop.65plus))

make_tab_boot_ci(models.list=list(e2, e3, e4, e5), 
                 file.boot.run="bootsttrapped.e2_e5.Rdata")

sapply(list(e2, e3, e4, e5), nobs)
sapply(list(e2, e3, e4, e5), ngrps)

### E2. Alternative indicators of country education  #####
### (government spending on secondary and tertiary education; population enrollment in secondary and tertiary education)


e6  <- update(m1, . ~ . + scale(gov.ed.expend.secondary ) )
e6a <- update(m1, . ~ . + scale(gov.ed.expend.secondary) + scale(pop.65plus))

e7  <- update(m1, . ~ . + scale(gov.ed.expend.total ))
e7a <- update(m1, . ~ . + scale(gov.ed.expend.total) + scale(pop.65plus))

e8  <- update(m1, . ~ . + scale(enrollment.secondary ))
e8a <- update(m1, . ~ . + scale(enrollment.secondary) + scale(pop.65plus))

e9  <- update(m1, . ~ . + scale(enrollment.tertiary))
e9a <- update(m1, . ~ . + scale(enrollment.tertiary) + scale(pop.65plus))

make_tab_boot_ci(models.list=list(e6, e6a, e7, e7a, e8, e8a, e9, e9a), 
                 file.boot.run="bootsttrapped.e6_e9.Rdata")
sapply(list(e6, e6a, e7, e7a, e8, e8a, e9, e9a), ngrps)

### E3. Share of employed among older people (smaller N at country level, 44) #####

e10 <- update(m1, . ~ . + scale(empl.older.ilo))
e11 <- update(m1, . ~ . + scale(empl.older.ilo) + scale(ind.modern) )
e12 <- update(m1, . ~ . + scale(empl.older.ilo )+ scale(log.gdp.pc) )
e13 <- update(m1, . ~ . + scale(empl.older.ilo) + scale(pop.65plus) )
e14 <- update(m1, . ~ . + scale(empl.older.ilo )+ scale(schooling.yrs) )
e15 <- update(m1, . ~ . + scale(empl.older.ilo )+  muslim.countries + postcommunist.countries1)

make_tab_boot_ci(models.list=list(e10, e11, e12, e13, e14, e15), 
                 file.boot.run="bootsttrapped.e10_e15.Rdata")
sapply(list(e10, e11, e12, e13, e14, e15), ngrps)

### E4. Government spending on older people as percent of GDP (N=48) #####

e16 <- update(m1, . ~ . + scale(soc.spend65.ilo))
e17 <- update(m1, . ~ . + scale(soc.spend65.ilo) + scale(ind.modern))
e18 <- update(m1, . ~ . + scale(soc.spend65.ilo) + scale(log.gdp.pc))
e19 <- update(m1, . ~ . + scale(soc.spend65.ilo) + scale(pop.65plus))
e20 <- update(m1, . ~ . + scale(soc.spend65.ilo) + scale(schooling.yrs))
e21 <- update(m1, . ~ . + scale(soc.spend65.ilo) + muslim.countries + postcommunist.countries1)

make_tab_boot_ci(models.list=list(e16, e17, e18, e19, e20, e21), 
                 file.boot.run="bootsttrapped.e16_e21.Rdata")
sapply(list(e16, e17, e18, e19, e20, e21), ngrps)



### E5. Effect of share of people 65+ after controlling for life expectancy #####

e22 <- update(m1, . ~ . + scale(life.exp))
e23 <- update(m1, . ~ . + scale(life.exp) + scale(ind.modern))
e24 <- update(m1, . ~ . + scale(life.exp) + scale(log.gdp.pc))
e25 <- update(m1, . ~ . + scale(life.exp) + scale(pop.65plus))
e26 <- update(m1, . ~ . + scale(life.exp) + scale(schooling.yrs))
e27 <- update(m1, . ~ . + scale(life.exp) + muslim.countries + postcommunist.countries1)
e28 <- update(m1, . ~ . + scale(life.exp) + muslim.countries + postcommunist.countries1 + scale(pop.65plus) )


make_tab_boot_ci(models.list=list(e22, e23, e24, e25, e26, e27), 
                 file.boot.run="bootsttrapped.e22_e27.Rdata")

sapply(list(e22, e23, e24, e25, e26, e27), ngrps)


### E6. Re-analysis with Slovenia categorized as a Postcommunist country #####

e28 <- update(m1, . ~ . + LatinAmerica +NewWorld + SouthEastAsia+ SSAfrica + muslim.countries  + postcommunist.countries + scale(ind.modern)) #OtherEurope
e29 <- update(m1, . ~ . + scale(ind.modern) +   
               scale(ind.modern)*muslim.countries  + 
               scale(ind.modern)*postcommunist.countries)
e30 <- update(m1, . ~ . + scale(log.gdp.pc) +   
                scale(log.gdp.pc)*muslim.countries  + 
                scale(log.gdp.pc)*postcommunist.countries)

e31 <- update(m1, . ~ . + scale(pop.65plus) +   
                scale(pop.65plus)*muslim.countries  + 
                scale(pop.65plus)*postcommunist.countries)

e32 <- update(m1, . ~ . + scale(schooling.yrs) +   
                scale(schooling.yrs)*muslim.countries  + 
                scale(schooling.yrs)*postcommunist.countries)
e33 <- update(m1, . ~ . + scale(urbanization) +   
                scale(urbanization)*muslim.countries  + 
                scale(urbanization)*postcommunist.countries)


make_tab_boot_ci(models.list=list(e28, e29, e30, e31, e32, e33), 
                 file.boot.run="bootsttrapped.e30_e33.Rdata")


### E7. Re-analysis dropping Japan and Germany ####


# correlations between pop65 and PSS70 with and without outliers Germany and Japan 
cor.test(gr.dat$pop.65, gr.dat$sss70, use = "complete")
cor.test(gr.dat$pop.65[!gr.dat$country %in% c("Japan", "Germany")], 
         gr.dat$sss70[!gr.dat$country %in% c("Japan", "Germany")], use = "complete")


#..dropping Germany and Japan  from models
e0 <- update(m1, . ~ ., 
             data = wvs_nomis[!wvs_nomis$country %in% c("Japan", "Germany"),])
e34 <- update(e0, . ~ . + scale(ind.modern)    + I(scale(ind.modern)^2))
e35 <- update(e0, . ~ . + scale(log.gdp.pc)    + I(scale(log.gdp.pc)^2))
e36 <- update(e0, . ~ . + scale(pop.65plus)    + I(scale(pop.65plus)^2))
e37 <- update(e0, . ~ . + scale(schooling.yrs) + I(scale(schooling.yrs)^2))
e38 <- update(e0, . ~ . + scale(urbanization)  + I(scale(urbanization)^2))
e39 <- update(e0, . ~ . + muslim.countries + postcommunist.countries1)
e40 <- update(e0, . ~ . + scale(ind.modern) +   
               scale(ind.modern)*muslim.countries  + 
               scale(ind.modern)*postcommunist.countries1)
e41 <- update(e0, . ~ . + muslim.countries  + postcommunist.countries1 + scale(pop.65plus) + I(scale(pop.65plus)^2)) 


make_tab_boot_ci(models.list=list(e34, e35, e36, e37, e38, e39, e40, e41), 
                 file.boot.run="bootsttrapped.e34_e40.Rdata")

